@@ -989,7 +989,7 @@ class _UNet(nn.Module):
             raise ValueError(f"n_layers = {self.n_layers}, expected: n_layers > 0")
 
         
-        self.dims = rearrange_dims(dims=dims, dataformats=dataformats) # (in_channels, height, width)
+        self.dims = rearrange_dims(dims=dims, in_format= dataformats, dataformats="NCHW") # (in_channels, height, width)
         self.input_channels = self.dims[0]
         super().__init__()
 
@@ -1122,7 +1122,8 @@ class _PixelCNN(nn.Module):
 
         self.blocks = nn.ModuleList([self.conv_block(in_channels) for _ in range(n_blocks)])
 
-        self.dims = rearrange_dims(dims=dims, dataformats=dataformats)
+        self.dims = rearrange_dims(dims=dims, in_format=dataformats, dataformats="NCHW")
+        
     def conv_block(self, in_channels):
         c1 = nn.Conv2d(in_channels=in_channels, out_channels=self.hidden_channels, kernel_size=(1,1))
         act1 = nn.ReLU()
