@@ -629,7 +629,7 @@ class BaseProject:
                         img = fig.add_subplot(rows, cols, idx)
                         if len(self.dims) > 2:
                             dims_imshow = rearrange_dims(self.dims, in_format=dataformats, dataformats="NHWC")
-                        img.imshow(self.X[sampling_idx][idx-1].reshape(dims_imshow))
+                        img.imshow(self.X[sampling_idx][idx-1].ravel().reshape(dims_imshow))
                         img.set_title(f'label : {labels_to_show[idx-1]}')
             plt.show()
             plt.savefig(f"{img_dir}/image_samples.png")       
